==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/catalog_move_para_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CatalogMoveParaDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'target_pid': 'str'
    }

    attribute_map = {
        'target_pid': 'target_pid'
    }

    def __init__(self, target_pid=None):
        """CatalogMoveParaDTO

        The model defined in huaweicloud sdk

        :param target_pid: 父目录编号
        :type target_pid: str
        """
        
        

        self._target_pid = None
        self.discriminator = None

        if target_pid is not None:
            self.target_pid = target_pid

    @property
    def target_pid(self):
        """Gets the target_pid of this CatalogMoveParaDTO.

        父目录编号

        :return: The target_pid of this CatalogMoveParaDTO.
        :rtype: str
        """
        return self._target_pid

    @target_pid.setter
    def target_pid(self, target_pid):
        """Sets the target_pid of this CatalogMoveParaDTO.

        父目录编号

        :param target_pid: The target_pid of this CatalogMoveParaDTO.
        :type target_pid: str
        """
        self._target_pid = target_pid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogMoveParaDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/catalog_move_para_dto.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CatalogMoveParaDTO:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'target_pid': 'str'
    }

    attribute_map = {
        'target_pid': 'target_pid'
    }

    def __init__(self, target_pid=None):
        r"""CatalogMoveParaDTO

        The model defined in huaweicloud sdk

        :param target_pid: 父目录编号
        :type target_pid: str
        """
        
        

        self._target_pid = None
        self.discriminator = None

        if target_pid is not None:
            self.target_pid = target_pid

    @property
    def target_pid(self):
        r"""Gets the target_pid of this CatalogMoveParaDTO.

        父目录编号

        :return: The target_pid of this CatalogMoveParaDTO.
        :rtype: str
        """
        return self._target_pid

    @target_pid.setter
    def target_pid(self, target_pid):
        r"""Sets the target_pid of this CatalogMoveParaDTO.

        父目录编号

        :param target_pid: The target_pid of this CatalogMoveParaDTO.
        :type target_pid: str
        """
        self._target_pid = target_pid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CatalogMoveParaDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
